[![PyPI](https://img.shields.io/pypi/v/dis-snek)](https://pypi.org/project/dis-snek/)
[![Downloads](https://static.pepy.tech/personalized-badge/dis-snek?period=total&units=abbreviation&left_color=grey&right_color=green&left_text=pip%20installs)](https://pepy.tech/project/dis-snek)
[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)
[![black-formatted](https://img.shields.io/github/workflow/status/Discord-Snake-Pit/dis-snek/black-action/master?label=Black%20Format&logo=github)](https://github.com/LordOfPolls/dis_snek/actions/workflows/black.yml)
[![CodeQL](https://img.shields.io/github/workflow/status/Discord-Snake-Pit/dis-snek/CodeQL/master?label=CodeQL&logo=Github)](https://github.com/LordOfPolls/dis_snek/actions/workflows/codeql-analysis.yml)
[![Discord](https://img.shields.io/discord/870046872864165888?color=%235865F2&label=Server&logo=discord&logoColor=%235865F2)](https://discord.gg/hpfNhH8BsY)
[![Documentation Status](https://readthedocs.org/projects/dis-snek/badge/?version=latest)](https://dis-snek.readthedocs.io/en/latest/?badge=latest)

# "What is this?"
This is `Dis-Snek`, an API wrapper for Discord, written in Python. This wrapper is designed to be easy to use, and easily modified to suit your needs.

#### Features: 
- ✅ 100% coverage of the application commands API 
- ✅ Modern and Pythonic API 
- ✅ Asynchronous operation
- ✅ Proper rate limit handling
- ✅ Dynamic cache with TTL support


## "Is this just another discord.py fork"?
While this library shares some features and stylistic choice with `discord.py`, its completely separate from them. We think `discord.py` is a fantastic library, but we disagree with the direction and design decisions made by it.

Compared to `discord.py`; `Snek` starts faster, responds faster, and is simpler to use. Especially compared to `Views`. 

## "I don't understand something"
If you need help with something, don’t hesitate to ask for help in the [Discord Server](https://discord.gg/NTSHu97tHg)!

## "Can I contribute to this project?"
Of course, you can contribute to this project by submitting a pull-request here. We also have a [Trello Board](https://trello.com/b/LVjnmYKt/dev-board) where you can see what we are working towards, feel free to do anything there.

## Links:

- Support Server: https://discord.gg/NTSHu97tHg
- Documentation:  https://dis-snek.rtfd.io/
- Trello: https://trello.com/b/LVjnmYKt/dev-board
